@@ -69,6 +69,20 @@ collector:
     test-helper: {fake_test_helper: 'fake_hostname'}
 """
 
+sample_bouncer_file = """
+collector:
+  httpo://ihiderha53f36lsd.onion:
+    test-helper: {dns: '64.9.225.221:57004', http-return-json-headers: 'http://64.9.225.221', ssl: 'https://64.9.225.221', tcp-echo: '213.138.109.232', traceroute: '64.9.225.221'}
+  httpo://vivlxvmlh3u6rqi6.onion:
+    test-helper: {dns: '64.9.225.221:57004', http-return-json-headers: 'http://64.9.225.221', ssl: 'https://64.9.225.221', tcp-echo: '213.138.109.232', traceroute: '64.9.225.221'}
+  httpo://5lsyitb6jzy35duu.onion:
+    test-helper: {dns: '64.9.225.221:57004', http-return-json-headers: 'http://64.9.225.221', ssl: 'https://64.9.225.221', tcp-echo: '213.138.109.232', traceroute: '64.9.225.221'}
+    policy:
+        nettest:
+        - {"name": "http_header_field_manipulation", version: 0.1.3}
+        input: []
+"""
+
 reports_dir = 'data/reports'
 archive_dir = 'data/archive'
 input_dir = 'data/inputs'
@@ -373,6 +387,37 @@ class TestDefaultCollector(BaseTestBouncer):
         self.assertIn('collector', response_body['net-tests'][0])
         self.assertEqual(response_body['net-tests'][0]['collector'], 'default_collector')
 
+class TestCanonicalBouncer(BaseTestBouncer):
+    app = web.Application(bouncerAPI, name='bouncerAPI')
+
+    def setUp(self, *args, **kw):
+        with open(bouncer_filename, 'w') as bouncer_file:
+            bouncer_file.write(sample_bouncer_file)
+        super(TestCanonicalBouncer, self).setUp()
+
+    @defer.inlineCallbacks
+    def test_complete_deck(self):
+        data = {'net-tests': [
+            {'test-helpers': [], 'version': '0.2.4',
+             'name': 'http_requests',
+             'input-hashes': ['37e60e13536f6afe47a830bfb6b371b5cf65da66d7ad65137344679b24fdccd1']},
+
+            {'test-helpers': ['dns'], 'version': '0.6',
+             'name': 'dns_consistency',
+             'input-hashes': ['37e60e13536f6afe47a830bfb6b371b5cf65da66d7ad65137344679b24fdccd1']},
+            {'test-helpers': ['tcp-echo'], 'version': '0.2', 'name': 'http_invalid_request_line',
+             'input-hashes': []},
+            {'test-helpers': ['http-return-json-headers'],
+             'version': '0.1.5',
+             'name': 'http_header_field_manipulation', 'input-hashes': []},
+            {'test-helpers': ['http-return-json-headers'],
+             'version': '0.2.4', 'name': 'http_host',
+             'input-hashes': ['37e60e13536f6afe47a830bfb6b371b5cf65da66d7ad65137344679b24fdccd1']}
+            ]
+        }
+        response = yield self.request('/bouncer/net-tests', 'POST', data)
+        print response.body
+
 
 class TestMultipleCollectors(BaseTestBouncer):
     app = web.Application(bouncerAPI, name='bouncerAPI')
